pyobjects_to_instrument_statuses

Function pyobjects_to_instrument_statuses 

pub fn pyobjects_to_instrument_statuses(
    data: Vec<Bound<'_, PyAny>>,
) -> PyResult<Vec<InstrumentStatus>>
Transforms the given Python objects into a vector of InstrumentStatus objects.

Errors

Returns a PyErr if element conversion fails or the data is not monotonically increasing.