pub fn pyobjects_to_instrument_statuses(
data: Vec<Bound<'_, PyAny>>,
) -> PyResult<Vec<InstrumentStatus>>Expand description
Transforms the given Python objects into a vector of InstrumentStatus objects.
Errors
Returns a PyErr if element conversion fails or the data is not monotonically increasing.